"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeRenderCreditsIx = exports.mintRenderCreditsIx = exports.distributeBurnRewardsIx = exports.updateRenderCreditsIx = void 0;
const bn_js_1 = __importDefault(require("bn.js"));
const spl_utils_1 = require("@render-foundation/spl-utils");
const anchor = __importStar(require("@coral-xyz/anchor"));
const constants_1 = require("./constants");
const pdas_1 = require("./pdas");
const circuit_breaker_sdk_1 = require("@render-foundation/circuit-breaker-sdk");
const emission_distributor_sdk_1 = require("@render-foundation/emission-distributor-sdk");
const updateRenderCreditsIx = (program, args) => {
    var _a, _b;
    return program.methods
        .updateRenderCreditsV0({
        authority: (_a = args.authority) !== null && _a !== void 0 ? _a : null,
        rndrPriceOracle: (_b = args.rndrPriceOracle) !== null && _b !== void 0 ? _b : null
    })
        .accounts({
        rcMint: args.rcMint,
        renderCredits: (0, pdas_1.renderCreditsKey)(args.rndrMint, args.rcMint)[0],
        rndrMint: args.rndrMint
    }).instruction();
};
exports.updateRenderCreditsIx = updateRenderCreditsIx;
const distributeBurnRewardsIx = (program, rndrMint, burner, epochId, emissionDistributorProgram = emission_distributor_sdk_1.PROGRAM_ID) => {
    return program.methods
        .distributeBurnRewardsV0({ epochId: new bn_js_1.default(epochId) })
        .accounts({
        burnStats: (0, pdas_1.burnStatsKey)(rndrMint, epochId, program.programId)[0],
        emissionScheduleReceipt: (0, emission_distributor_sdk_1.emissionScheduleReceiptKey)(rndrMint, epochId, emissionDistributorProgram)[0],
        owner: burner,
        burnRewardsVoucher: (0, pdas_1.burnRewardsVoucherKey)(burner, epochId, program.programId)[0],
        rndrMint: rndrMint,
        emissionDistributorProgram
    })
        .instruction();
};
exports.distributeBurnRewardsIx = distributeBurnRewardsIx;
const mintRenderCreditsIx = (program, args, emissionDistributorProgram = emission_distributor_sdk_1.PROGRAM_ID) => {
    let { rndrMint, rcMint, burner, rndrAmount, receiver } = args;
    return program.methods
        .mintRenderCreditsV0({
        rndrAmount: (0, spl_utils_1.toBN)(rndrAmount, rndrMint.decimals),
        rcAmount: null,
    })
        .accounts({
        rcMint,
        recipient: receiver !== null && receiver !== void 0 ? receiver : burner,
        owner: burner,
        emissionSchedule: (0, emission_distributor_sdk_1.emissionScheduleKey)(rndrMint.address, emissionDistributorProgram)[0],
        renderCredits: (0, pdas_1.renderCreditsKey)(rndrMint.address, rcMint, program.programId)[0],
        rndrPriceOracle: constants_1.PROD_RNDR_PRICE_ORACLE,
        rndrMint: rndrMint.address,
        emissionDistributorProgram
    }).instruction();
};
exports.mintRenderCreditsIx = mintRenderCreditsIx;
const initializeRenderCreditsIx = (program, rndrMint, rcMint, args, accts, 
/*
new PublicKey(
  "distZXJ5FYrPhjBhB5P2BQ9B2AsPzJ4TcUSz6hKssP1"
)
new PublicKey(
  "circiqFCstNzaFBji1udQ6txgQBrn29pVSYHNJQo3wZ"
)
 */
emissionDistributorProgram = emission_distributor_sdk_1.PROGRAM_ID, circuitBreakerProgram = circuit_breaker_sdk_1.PROGRAM_ID) => {
    var _a;
    const burnRewardsEscrowK = (0, pdas_1.networkNodeOperatorsEscrow)(rndrMint.address, program.programId)[0];
    return program
        .methods
        .initializeRenderCreditsV0({
        authority: args.authority,
        mintConfig: args.mintBreakerConfig,
        escrowConfig: args.escrowBreakerConfig
    })
        .preInstructions([anchor.web3.ComputeBudgetProgram.setComputeUnitLimit({
            units: 1400000,
        })])
        .accounts({
        renderCredits: (0, pdas_1.renderCreditsKey)(rndrMint.address, rcMint, program.programId)[0],
        rndrMint: rndrMint.address,
        rcMintBreaker: (0, circuit_breaker_sdk_1.mintWindowedBreakerKey)(rcMint, circuitBreakerProgram)[0],
        rndrMintBreaker: (0, circuit_breaker_sdk_1.mintWindowedBreakerKey)(rndrMint.address, circuitBreakerProgram)[0],
        burnEscrowBreaker: (0, circuit_breaker_sdk_1.accountWindowedBreakerKey)(burnRewardsEscrowK, circuitBreakerProgram)[0],
        rcMint: rcMint,
        payer: args.authority,
        rndrPriceOracle: constants_1.PROD_RNDR_PRICE_ORACLE,
        mintAuthority: accts.mintAuthority,
        freezeAuthority: (_a = accts.freezeAuthority) !== null && _a !== void 0 ? _a : accts.mintAuthority,
        emissionDistributorProgram,
        circuitBreakerProgram
    }).instruction();
};
exports.initializeRenderCreditsIx = initializeRenderCreditsIx;
//# sourceMappingURL=instructions.js.map