"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderCreditsResolvers = void 0;
const spl_utils_1 = require("@render-foundation/spl-utils");
const circuit_breaker_sdk_1 = require("@render-foundation/circuit-breaker-sdk");
const emission_distributor_sdk_1 = require("@render-foundation/emission-distributor-sdk");
const index_1 = require("./index");
exports.renderCreditsResolvers = (0, spl_utils_1.combineResolvers)(spl_utils_1.renderCommonResolver, circuit_breaker_sdk_1.circuitBreakerResolvers, (0, spl_utils_1.ataResolver)({
    instruction: "mintRenderCreditsV0",
    account: "recipientTokenAccount",
    mint: "rcMint",
    owner: "recipient",
}), (0, spl_utils_1.ataResolver)({
    instruction: "mintRenderCreditsV0",
    account: "burner",
    mint: "rndrMint",
    owner: "owner",
}), (0, spl_utils_1.ataResolver)({
    instruction: "burnRenderCreditsV0",
    account: "burner",
    mint: "rcMint",
    owner: "owner",
}), (0, spl_utils_1.ataResolver)({
    instruction: "distributeBurnRewardsV0",
    account: "to",
    mint: "rndrMint",
    owner: "owner",
}), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "emissionSchedule" && idlIx.name === "distributeBurnRewardsV0") {
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionDistributorPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        return (0, emission_distributor_sdk_1.emissionScheduleKey)(rndrMintK, emissionDistributorPid)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "recipient" && !accounts.recipient && provider.wallet) {
        return provider.wallet.publicKey;
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "burnRewardsVoucher" && idlIx.name === "mintRenderCreditsV0") {
        const emissionDistributorPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        const program = yield (0, emission_distributor_sdk_1.init)(provider, emissionDistributorPid, true);
        const emissionScheduleK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionSchedule",
        ]);
        const ownerK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "owner",
        ]);
        const emissionSchedule = yield program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return (0, index_1.burnRewardsVoucherKey)(ownerK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "burnRewardsEscrow") {
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return (0, index_1.networkNodeOperatorsEscrow)(rndrMintK, programId)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "burnRewardsRedeemer") {
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return (0, index_1.burnRewardsRedeemerKey)(rndrMintK, programId)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "emissionDistributor" && idlIx.name === "initializeRenderCreditsV0") {
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionDistributorPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        return (0, emission_distributor_sdk_1.emissionDistributorKey)(rndrMintK, emissionDistributorPid)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, programId, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "circuitBreaker" && (idlIx.name === "distributeBurnRewardsV0" || idlIx.name === "mintRenderCreditsV0")) {
        const circuitBreakerPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "circuitBreakerProgram",
        ]);
        if (idlIx.name === "distributeBurnRewardsV0") {
            const rndrMintK = (0, spl_utils_1.get)(accounts, [
                ...path.slice(0, path.length - 1),
                "rndrMint",
            ]);
            const beK = (0, index_1.networkNodeOperatorsEscrow)(rndrMintK, programId)[0];
            return (0, circuit_breaker_sdk_1.accountWindowedBreakerKey)(beK, circuitBreakerPid)[0];
        }
        const rcMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rcMint",
        ]);
        return (0, circuit_breaker_sdk_1.mintWindowedBreakerKey)(rcMintK, circuitBreakerPid)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === "burnStats" && idlIx.name == "mintRenderCreditsV0") {
        const emissionDistributorPid = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        const program = yield (0, emission_distributor_sdk_1.init)(provider, emissionDistributorPid, true);
        const emissionScheduleK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionSchedule",
        ]);
        const rndrMintK = (0, spl_utils_1.get)(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionSchedule = yield program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return (0, index_1.burnStatsKey)(rndrMintK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
})));
//# sourceMappingURL=resolvers.js.map