import BN from "bn.js";
import { toBN } from "@render-foundation/spl-utils";
import * as anchor from "@coral-xyz/anchor";
import { PROD_RNDR_PRICE_ORACLE } from "./constants";
import { networkNodeOperatorsEscrow, burnRewardsVoucherKey, burnStatsKey, renderCreditsKey } from "./pdas";
import { accountWindowedBreakerKey, mintWindowedBreakerKey, PROGRAM_ID as CIRCUIT_BREAKER_PROGRAM_ID } from "@render-foundation/circuit-breaker-sdk";
import { emissionScheduleKey, emissionScheduleReceiptKey, PROGRAM_ID as EMISSION_DISTRIBUTOR_PROGRAM_ID } from "@render-foundation/emission-distributor-sdk";
export const updateRenderCreditsIx = (program, args) => {
    return program.methods
        .updateRenderCreditsV0({
        authority: args.authority ?? null,
        rndrPriceOracle: args.rndrPriceOracle ?? null
    })
        .accounts({
        rcMint: args.rcMint,
        renderCredits: renderCreditsKey(args.rndrMint, args.rcMint)[0],
        rndrMint: args.rndrMint
    }).instruction();
};
export const distributeBurnRewardsIx = (program, rndrMint, burner, epochId, emissionDistributorProgram = EMISSION_DISTRIBUTOR_PROGRAM_ID) => {
    return program.methods
        .distributeBurnRewardsV0({ epochId: new BN(epochId) })
        .accounts({
        burnStats: burnStatsKey(rndrMint, epochId, program.programId)[0],
        emissionScheduleReceipt: emissionScheduleReceiptKey(rndrMint, epochId, emissionDistributorProgram)[0],
        owner: burner,
        burnRewardsVoucher: burnRewardsVoucherKey(burner, epochId, program.programId)[0],
        rndrMint: rndrMint,
        emissionDistributorProgram
    })
        .instruction();
};
export const mintRenderCreditsIx = (program, args, emissionDistributorProgram = EMISSION_DISTRIBUTOR_PROGRAM_ID) => {
    let { rndrMint, rcMint, burner, rndrAmount, receiver } = args;
    return program.methods
        .mintRenderCreditsV0({
        rndrAmount: toBN(rndrAmount, rndrMint.decimals),
        rcAmount: null,
    })
        .accounts({
        rcMint,
        recipient: receiver ?? burner,
        owner: burner,
        emissionSchedule: emissionScheduleKey(rndrMint.address, emissionDistributorProgram)[0],
        renderCredits: renderCreditsKey(rndrMint.address, rcMint, program.programId)[0],
        rndrPriceOracle: PROD_RNDR_PRICE_ORACLE,
        rndrMint: rndrMint.address,
        emissionDistributorProgram
    }).instruction();
};
export const initializeRenderCreditsIx = (program, rndrMint, rcMint, args, accts, 
/*
new PublicKey(
  "distZXJ5FYrPhjBhB5P2BQ9B2AsPzJ4TcUSz6hKssP1"
)
new PublicKey(
  "circiqFCstNzaFBji1udQ6txgQBrn29pVSYHNJQo3wZ"
)
 */
emissionDistributorProgram = EMISSION_DISTRIBUTOR_PROGRAM_ID, circuitBreakerProgram = CIRCUIT_BREAKER_PROGRAM_ID) => {
    const burnRewardsEscrowK = networkNodeOperatorsEscrow(rndrMint.address, program.programId)[0];
    return program
        .methods
        .initializeRenderCreditsV0({
        authority: args.authority,
        mintConfig: args.mintBreakerConfig,
        escrowConfig: args.escrowBreakerConfig
    })
        .preInstructions([anchor.web3.ComputeBudgetProgram.setComputeUnitLimit({
            units: 1400000,
        })])
        .accounts({
        renderCredits: renderCreditsKey(rndrMint.address, rcMint, program.programId)[0],
        rndrMint: rndrMint.address,
        rcMintBreaker: mintWindowedBreakerKey(rcMint, circuitBreakerProgram)[0],
        rndrMintBreaker: mintWindowedBreakerKey(rndrMint.address, circuitBreakerProgram)[0],
        burnEscrowBreaker: accountWindowedBreakerKey(burnRewardsEscrowK, circuitBreakerProgram)[0],
        rcMint: rcMint,
        payer: args.authority,
        rndrPriceOracle: PROD_RNDR_PRICE_ORACLE,
        mintAuthority: accts.mintAuthority,
        freezeAuthority: accts.freezeAuthority ?? accts.mintAuthority,
        emissionDistributorProgram,
        circuitBreakerProgram
    }).instruction();
};
//# sourceMappingURL=instructions.js.map