import { ataResolver, combineResolvers, get, renderCommonResolver, resolveIndividual } from "@render-foundation/spl-utils";
import { accountWindowedBreakerKey, circuitBreakerResolvers, mintWindowedBreakerKey } from "@render-foundation/circuit-breaker-sdk";
import { emissionDistributorKey, emissionScheduleKey, init as initializeEmissionDistributor } from "@render-foundation/emission-distributor-sdk";
import { networkNodeOperatorsEscrow, burnRewardsVoucherKey, burnStatsKey, burnRewardsRedeemerKey } from "./index";
export const renderCreditsResolvers = combineResolvers(renderCommonResolver, circuitBreakerResolvers, ataResolver({
    instruction: "mintRenderCreditsV0",
    account: "recipientTokenAccount",
    mint: "rcMint",
    owner: "recipient",
}), ataResolver({
    instruction: "mintRenderCreditsV0",
    account: "burner",
    mint: "rndrMint",
    owner: "owner",
}), ataResolver({
    instruction: "burnRenderCreditsV0",
    account: "burner",
    mint: "rcMint",
    owner: "owner",
}), ataResolver({
    instruction: "distributeBurnRewardsV0",
    account: "to",
    mint: "rndrMint",
    owner: "owner",
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === "emissionSchedule" && idlIx.name === "distributeBurnRewardsV0") {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        return emissionScheduleKey(rndrMintK, emissionDistributorPid)[0];
    }
}), resolveIndividual(async ({ path, accounts, provider, args }) => {
    if (path[path.length - 1] === "recipient" && !accounts.recipient && provider.wallet) {
        return provider.wallet.publicKey;
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, programId, args }) => {
    if (path[path.length - 1] === "burnRewardsVoucher" && idlIx.name === "mintRenderCreditsV0") {
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        const program = await initializeEmissionDistributor(provider, emissionDistributorPid, true);
        const emissionScheduleK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionSchedule",
        ]);
        const ownerK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "owner",
        ]);
        const emissionSchedule = await program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return burnRewardsVoucherKey(ownerK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
}), resolveIndividual(async ({ path, accounts, provider, programId, args }) => {
    if (path[path.length - 1] === "burnRewardsEscrow") {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return networkNodeOperatorsEscrow(rndrMintK, programId)[0];
    }
}), resolveIndividual(async ({ path, accounts, provider, programId, args }) => {
    if (path[path.length - 1] === "burnRewardsRedeemer") {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        return burnRewardsRedeemerKey(rndrMintK, programId)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === "emissionDistributor" && idlIx.name === "initializeRenderCreditsV0") {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        return emissionDistributorKey(rndrMintK, emissionDistributorPid)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, programId, provider, args }) => {
    if (path[path.length - 1] === "circuitBreaker" && (idlIx.name === "distributeBurnRewardsV0" || idlIx.name === "mintRenderCreditsV0")) {
        const circuitBreakerPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "circuitBreakerProgram",
        ]);
        if (idlIx.name === "distributeBurnRewardsV0") {
            const rndrMintK = get(accounts, [
                ...path.slice(0, path.length - 1),
                "rndrMint",
            ]);
            const beK = networkNodeOperatorsEscrow(rndrMintK, programId)[0];
            return accountWindowedBreakerKey(beK, circuitBreakerPid)[0];
        }
        const rcMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rcMint",
        ]);
        return mintWindowedBreakerKey(rcMintK, circuitBreakerPid)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, programId, args }) => {
    if (path[path.length - 1] === "burnStats" && idlIx.name == "mintRenderCreditsV0") {
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionDistributorProgram",
        ]);
        const program = await initializeEmissionDistributor(provider, emissionDistributorPid, true);
        const emissionScheduleK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "emissionSchedule",
        ]);
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            "rndrMint",
        ]);
        const emissionSchedule = await program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return burnStatsKey(rndrMintK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
}));
//# sourceMappingURL=resolvers.js.map